
.. _algorithms/clustering:

Clustering
**********

Algorithms
----------

.. automodule:: jgrapht.algorithms.clustering
   :members:

Types
-----

Vertex clusterings are represented using instances of the following class.

.. autoclass:: jgrapht.types.Clustering
   :members:

